@@ -25,9 +25,9 @@
 #include "kdfprivate_debug.h"
 #include "kdfutil.h"
 
-#include <kconfiggroup.h>
-#include <klocalizedstring.h>
-#include <kprocess.h>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KProcess>
 
 #include <QTextStream>
 #include <QFile>
@@ -610,8 +610,8 @@ void DiskList::replaceDeviceEntry(DiskEntry * disk)
                 (disk->percentFull() >= Full_Percent) )
         {
             qCDebug(KDF) << "Device " << disk->deviceName()
-            << " is critFull! " << olddisk->percentFull()
-            << "--" << disk->percentFull() << endl;
+                         << " is critFull! " << olddisk->percentFull()
+                         << "--" << disk->percentFull();
             emit criticallyFull(disk);
         }
 
